==> lxqt-session_0.17.1.orig.tar.xz: lxqt-session-0.17.1/lxqt-config-session/translations/lxqt-config-session_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Cercar...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Comanda :</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Esperar l’execucion del system-tray</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Causir aplicacion</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Aviada automatica globala</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Aviada automatica de LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Emplaçament : %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Remplaçament : %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Suprimir</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ajustar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Aviada automatica d’aplicacion</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Lo fichièr « %1 » existís ja !</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Paramètres de basa</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Gestionari de fenèstras</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Recercar...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Moduls de LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Aviar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Arrestar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>Quitar la session</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Demandar la confirmacion per quitar la session</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Verrolhar l’ecran abans de suspendre/ivernar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="131"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Suspendre/Ivernar aprèp lo relambi de verrolhatge :</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="144"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>Select a window manager</source>
        <translation>Seleccionar un gestionari de fenèstras</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Apondre</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Suprimir</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Variablas d’environament (avançat)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nom de la variabla</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>En execucion</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Paramètre de la session LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Paramètres de basa</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Repertòri utilizaire</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Aviada automatica</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Environament (avançat)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="87"/>
        <source>Session Restart Required</source>
        <translation>Reaviada de session requerit</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="88"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>D’unes paramètres seràn sonque preses en compte a la session venenta.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Emplaçament dels fichièrs personalas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Paramètres de LXQt - Repertòris utilizaire</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="186"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>S&apos;es producha una error pendent l’aplicacion dels paramètres per l’emplaçament %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="202"/>
        <source>Choose Location</source>
        <translation>Causir un emplaçament</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Burèu</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Telecargaments</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Modèls</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Espaci public</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Vidèos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Conten totes los fichièrs visibles pel burèu</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Repertòri per defaut de vòstres telecargaments</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Repertòri per defaut de vòstres modèls</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Repertòri per defaut per partejar publicament vòstres fichièrs</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Repertòri per defaut de vòstres documents</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Dossièr per defaut per cargar o salvar la musica</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Repertòri per defaut de vòstres imatges</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Repertòri per defaut de vòstras vidèos</translation>
    </message>
</context>
</TS>

==> lxqt-session_1.1.1.orig.tar.xz: lxqt-session-1.1.1/lxqt-config-session/translations/lxqt-config-session_oc.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="oc">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nom :</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Cercar...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Comanda :</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Esperar l’execucion del system-tray</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Causir aplicacion</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Aviada automatica globala</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Aviada automatica de LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Emplaçament : %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Remplaçament : %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Suprimir</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Ajustar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Modificar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Aviada automatica d’aplicacion</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Lo fichièr « %1 » existís ja !</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Paramètres de basa</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Gestionari de fenèstras</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Recercar...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Moduls de LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Aviar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Arrestar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation>Mesa a l’escala globala de l’ecran</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation>Factor d’escala :</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>Quitar la session</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Demandar la confirmacion per quitar la session</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Verrolhar l’ecran abans de suspendre/ivernar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Suspendre/Ivernar aprèp lo relambi de verrolhatge :</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Seleccionar un gestionari de fenèstras</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Apondre</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Suprimir</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Variablas d’environament (avançat)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nom de la variabla</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>En execucion</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Paramètre de la session LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Paramètres de basa</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Repertòri utilizaire</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Aviada automatica</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Environament (avançat)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>Reaviada de session requerit</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>D’unes paramètres seràn sonque preses en compte a la session venenta.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Emplaçament dels fichièrs personalas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Paramètres de LXQt - Repertòris utilizaire</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>S&apos;es producha una error pendent l’aplicacion dels paramètres per l’emplaçament %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Causir un emplaçament</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Burèu</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Telecargaments</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Modèls</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Espaci public</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Documents</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Musica</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Vidèos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Conten totes los fichièrs visibles pel burèu</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Repertòri per defaut de vòstres telecargaments</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Repertòri per defaut de vòstres modèls</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Repertòri per defaut per partejar publicament vòstres fichièrs</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Repertòri per defaut de vòstres documents</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Dossièr per defaut per cargar o salvar la musica</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Repertòri per defaut de vòstres imatges</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Repertòri per defaut de vòstras vidèos</translation>
    </message>
</context>
</TS>
